@@ -840,28 +840,56 @@ class StatsEngine(object):
         record['name'] = name
         record['timestamp'] = transaction.start_time
         record['duration'] = transaction.duration
-        record['nr.guid'] = transaction.guid
+
+        def _add_if_not_empty(key, value):
+            if value:
+                record[key] = value
+
+        if transaction.path_hash:
+            record['nr.guid'] = transaction.guid
+            record['nr.tripId'] = transaction.trip_id
+            record['nr.pathHash'] = transaction.path_hash
+
+            _add_if_not_empty('nr.referringPathHash',
+                    transaction.referring_path_hash)
+            _add_if_not_empty('nr.alternatePathHashes',
+                    ','.join(transaction.alternate_path_hashes))
+            _add_if_not_empty('nr.referringTransactionGuid',
+                    transaction.referring_transaction_guid)
+            _add_if_not_empty('nr.apdexPerfZone',
+                    transaction.apdex_perf_zone())
 
         # Add the Synthetics attributes to the 'records' dict.
 
         if transaction.synthetics_resource_id:
+            record['nr.guid'] = transaction.guid
             txn = transaction
             record['nr.syntheticsResourceId'] = txn.synthetics_resource_id
             record['nr.syntheticsJobId'] = txn.synthetics_job_id
             record['nr.syntheticsMonitorId'] = txn.synthetics_monitor_id
 
-        def _update_entry(source, target):
+        def _add_call_time(source, target):
             try:
                 record[target] = self.__stats_table[
                         (source, '')].total_call_time
             except KeyError:
                 pass
 
-        _update_entry('WebFrontend/QueueTime', 'queueDuration')
+        def _add_call_count(source, target):
+            try:
+                record[target] = self.__stats_table[
+                        (source, '')].call_count
+            except KeyError:
+                pass
 
-        _update_entry('External/all', 'externalDuration')
-        _update_entry('Database/all', 'databaseDuration')
-        _update_entry('Memcache/all', 'memcacheDuration')
+        _add_call_time('WebFrontend/QueueTime', 'queueDuration')
+
+        _add_call_time('External/all', 'externalDuration')
+        _add_call_time('Database/all', 'databaseDuration')
+        _add_call_time('Memcache/all', 'memcacheDuration')
+
+        _add_call_count('External/all', 'externalCallCount')
+        _add_call_count('Database/all', 'databaseCallCount')
 
         analytic_event = [record, params]
         return analytic_event
